@@ -8,36 +8,49 @@
 //! **Note: Normal handlers won't work as they MUST assume that
 //! the first argument is that of the binaries name.**
 
-use crate::*;
-pub use crate::handler::{app::{CommandLineHandler, DefaultCommandLineHandler}, DefaultAsyncCLIHandler};
-use serde::{Deserialize, Serialize};
+use std::collections::HashMap;
 use std::convert::TryFrom;
 use std::env;
 use std::error::Error;
+use std::fmt::Display;
 use std::fs;
+use std::io::{Read, Write};
+
 #[cfg(feature = "async-std")]
 use async_std::prelude::*;
+use serde::{Deserialize, Serialize};
 #[cfg(feature = "tokio")]
 use tokio::io::AsyncWriteExt;
 
+pub use crate::handler::app::{CommandLineHandler, DefaultCommandLineHandler};
+#[cfg(feature = "async")]
+use crate::handler::async_app::DefaultAsyncCLIHandler;
+use crate::*;
+
 /// See the module level dicumentation. Note `App` closely mirrors state and
 /// so can be created from it (given the right trait bounds)
 pub struct App<
+    'b,
     T: Serialize + for<'a> Deserialize<'a>,
     H: CommandLineHandler,
 > {
-    pub commands: HashMap<String, Command<T>>,
+    pub commands: HashMap<&'b str, Command<T>>,
     pub state: T,
     pub handler: H,
     pub description: String,
 }
 
-impl<T: Serialize + for<'a> Deserialize<'a>, M: Display, H: Handler<T>>
-    TryFrom<Shell<T, M, H>> for App<T, DefaultCommandLineHandler>
+impl<
+        'f: 't,
+        't,
+        T: Serialize + for<'a> Deserialize<'a>,
+        M: Display,
+        H: Handler<T>,
+    > TryFrom<Shell<'f, T, M, H>> for App<'t, T, DefaultCommandLineHandler>
 {
     type Error = Box<dyn Error>;
 
-    fn try_from(shell: Shell<T, M, H>) -> Result<Self, Box<dyn Error>> {
+    fn try_from(shell: Shell<'f, T, M, H>) -> Result<Self, Box<dyn Error>> {
         let mut this = Self {
             commands: shell.commands,
             state: shell.state,
@@ -49,10 +62,13 @@ impl<T: Serialize + for<'a> Deserialize<'a>, M: Display, H: Handler<T>>
     }
 }
 
-impl<T: Serialize + for<'a> Deserialize<'a> + Send>
-    App<T, DefaultAsyncCLIHandler>
+#[cfg(feature = "async")]
+impl<'f: 't, 't, T: Serialize + for<'a> Deserialize<'a> + Send>
+    App<'t, T, DefaultAsyncCLIHandler>
 {
-    pub fn try_from_async<M: Display, H: AsyncHandler<T>>(shell: Shell<T, M, H>) -> Result<Self, Box<dyn Error>> {
+    pub fn try_from_async<M: Display, H: AsyncHandler<T>>(
+        shell: Shell<'f, T, M, H>,
+    ) -> Result<Self, Box<dyn Error>> {
         let mut this = Self {
             commands: shell.commands,
             state: shell.state,
@@ -64,7 +80,9 @@ impl<T: Serialize + for<'a> Deserialize<'a> + Send>
     }
 }
 
-impl<T: Serialize + for<'a> Deserialize<'a>> App<T, DefaultCommandLineHandler> {
+impl<T: Serialize + for<'a> Deserialize<'a>>
+    App<'_, T, DefaultCommandLineHandler>
+{
     /// Creates a new shell
     pub fn new(state: T, project_name: String) -> Result<Self, Box<dyn Error>> {
         let mut this = Self {
@@ -80,10 +98,8 @@ impl<T: Serialize + for<'a> Deserialize<'a>> App<T, DefaultCommandLineHandler> {
     }
 }
 
-impl<
-        T: Serialize + for<'a> Deserialize<'a>,
-        H: CommandLineHandler,
-    > App<T, H>
+impl<T: Serialize + for<'a> Deserialize<'a>, H: CommandLineHandler>
+    App<'_, T, H>
 {
     /// Creates a new shell with the given handler.
     ///
@@ -124,9 +140,8 @@ impl<
 impl<
         T: Serialize + for<'a> Deserialize<'a>,
         H: CommandLineHandler + Handler<T>,
-    > App<T, H>
+    > App<'_, T, H>
 {
-
     /// Handles an vec of strings, like environment arguments.
     ///
     /// Returns a bool on wether we have 'quit' or not
@@ -171,22 +186,28 @@ impl<
     }
 }
 
+#[cfg(feature = "async")]
 impl<
         T: Serialize + for<'a> Deserialize<'a> + Send,
         H: CommandLineHandler + AsyncHandler<T>,
-    > App<T, H>
+    > App<'_, T, H>
 {
-
     /// Handles an vec of strings, like environment arguments.
     ///
     /// Returns a bool on wether we have 'quit' or not
-    pub async fn run_vec_async(&mut self, vec: Vec<String>) -> std::io::Result<bool> {
-        let result = self.handler.handle_async(
-            vec,
-            &self.commands,
-            &mut self.state,
-            &self.description,
-        ).await;
+    pub async fn run_vec_async(
+        &mut self,
+        vec: Vec<String>,
+    ) -> std::io::Result<bool> {
+        let result = self
+            .handler
+            .handle_async(
+                vec,
+                &self.commands,
+                &mut self.state,
+                &self.description,
+            )
+            .await;
 
         // Do stuff with the cache
         match result {
