@@ -1,7 +1,6 @@
 use std::error::Error;
-
 #[cfg(feature = "async")]
-use std::{ future::Future, pin::Pin };
+use std::{future::Future, pin::Pin};
 
 // NOTE: Taken from StackOverflow
 /// Use this macro to wrap an asynchronous function so that it can be used
@@ -46,60 +45,61 @@ impl<T> Command<T> {
     /// use shellfish::*;
     /// use std::error::Error;
     ///
-    /// fn greet(_state: (), args: Vec<String>) -> Result<(), Box<dyn Error> {
+    /// fn greet(_state: &mut (), args: Vec<String>) -> Result<(), Box<dyn Error>> {
     ///     //--snip--
+    ///     # Ok(())
     /// }
-    /// 
+    ///
     /// fn main() {
     ///     // Creates a shell
-    ///     let shell = Shell::new((), "[Shell]-$");
+    ///     let mut shell = Shell::new((), "[Shell]-$");
     ///
     ///     // Creates a command
     ///     shell.commands.insert(
-    ///         "greet".to_string(),
-    ///         Command::new("greets_you".to_string(), greet);
+    ///         "greet",
+    ///         Command::new("greets_you".to_string(), greet),
     ///     );
     /// }
     /// ```
     pub fn new(help: String, command: CommandFn<T>) -> Self {
-        Self { command: CommandType::Sync(command), help }
+        Self {
+            command: CommandType::Sync(command),
+            help,
+        }
     }
 
     /// Creates a new asynchronous `Command`.
     ///
     /// It is important to note that you have to call
     /// [`async_fn!`](async_fn!) to prepare a function for it.
-    /// 
+    ///
     /// # Example
     ///
     /// ```rust
     /// use shellfish::*;
     /// use std::error::Error;
     ///
-    /// #[macro_use]
-    /// extern crate shellfish;
-    ///
-    /// async fn greet(_state: (), args: Vec<String>) -> Result<(), Box<dyn Error> {
+    /// async fn greet(_state: &mut (), args: Vec<String>) -> Result<(), Box<dyn Error>> {
     ///     //--snip--
+    ///     # Ok(())
     /// }
     ///
-    /// #[tokio::main]
-    /// fn main() {
+    /// async fn async_main() {
     ///     // Creates a shell
-    ///     let shell = Shell::new((), "[Shell]-$");
+    ///     let mut shell = Shell::new((), "[Shell]-$");
     ///
     ///     // Creates a command
     ///     shell.commands.insert(
-    ///         "greet".to_string(),
-    ///         Command::new_async("greets_you".to_string(), async_fn!((), greet));
+    ///         "greet",
+    ///         Command::new_async("greets_you".to_string(), async_fn!((), greet)),
     ///     );
     /// }
     /// ```
     #[cfg(feature = "async")]
-    pub async fn new_async(help: String, command: AsyncCommandFn<T>) -> Self {
+    pub fn new_async(help: String, command: AsyncCommandFn<T>) -> Self {
         Self {
             command: CommandType::Async(command),
-            help
+            help,
         }
     }
 }
@@ -116,7 +116,12 @@ pub type CommandFn<T> = fn(&mut T, Vec<String>) -> Result<(), Box<dyn Error>>;
 /// To prepare for this you have to use the [`async_fn!`](async_fn!)
 /// macro to prepare the function.
 #[cfg(feature = "async")]
-pub type AsyncCommandFn<T> = fn(&mut T, Vec<String>) -> Pin<Box<dyn Future<Output = Result<(), Box< dyn Error>>> + Send + '_ >>;
+pub type AsyncCommandFn<T> = fn(
+    &mut T,
+    Vec<String>,
+) -> Pin<
+    Box<dyn Future<Output = Result<(), Box<dyn Error>>> + Send + '_>,
+>;
 
 /// Command type specifies what type of command this is, namely wether it
 /// is async or not.
