@@ -1,11 +1,13 @@
-use crate::Command;
-use crate::Handler;
 use std::collections::HashMap;
 use std::env;
 use std::path::PathBuf;
-use crate::command::CommandType;
+
 use yansi::Paint;
 
+use crate::command::CommandType;
+use crate::Command;
+use crate::Handler;
+
 pub trait CommandLineHandler {
     /// This is where the cache is stored:
     ///
@@ -54,7 +56,7 @@ impl<T> Handler<T> for DefaultCommandLineHandler {
     fn handle(
         &self,
         line: Vec<String>,
-        commands: &HashMap<String, Command<T>>,
+        commands: &HashMap<&str, Command<T>>,
         state: &mut T,
         description: &str,
     ) -> bool {
@@ -111,7 +113,7 @@ impl<T> Handler<T> for DefaultCommandLineHandler {
                     }
                 }
                 _ => {
-                    let command = commands.get(command);
+                    let command = commands.get(&command as &str);
                     let line =
                         line[1..].iter().map(|x| x.to_string()).collect();
 
